function U = FindElasticCovariance(mu,q)

close all;

reparamFlag = 1;
[a,b,n]=size(q);

% Compute inverse exponential map at the mean SRVF
for i=1:n
    tmp = ElasticShootingVector(mu,q(:,:,i),reparamFlag);
    VV(i,1:b) = tmp(1,:);
    VV(i,b+1:2*b) = tmp(2,:);
end

% Compute covariance and perform PCA
K = cov(VV);
[U,S,V] = svd(K);

T = length(VV(1,:))/2;
s = sqrt(diag(S));

% Display the first principal direction of variability
i=1;
figure(11); clf; hold on;
for t=-3:1:3
    u = t*s(i)*U(:,i)'/2;
    UU(1,1:T) = u(1:T);
    UU(2,1:T) = u(T+1:2*T);
    UUn=UU;
    
    q = ElasticShooting(mu,UUn);
   
    
    p = q_to_curve(q);
    
    
    if (t==0)
        plot(t*0.32+p(1,:),p(2,:),'r','LineWidth',2);
    else
        plot(t*0.32+p(1,:),p(2,:),'LineWidth',2);
    end
    axis equal off;
end

% Display the second principal direction of variability
i = 2;
figure(12); clf; hold on;
for t=-3:1:3
    u = t*s(i)*U(:,i)'/2;
    UU(1,1:T) = u(1:T);
    UU(2,1:T) = u(T+1:2*T);
    UUn=UU;
    
    q = ElasticShooting(mu,UUn);   
    p = q_to_curve(q);
    

    if (t==0)
        plot(t*0.31+p(1,:),p(2,:),'r','LineWidth',2);
    else
        plot(t*0.31+p(1,:),p(2,:),'LineWidth',2);
    end
    axis equal off;
end

% Display seven random samples from wrapped Gaussian distribution
mun=mean(VV);
idx=1;
figure(17); clf; hold on;
while(idx<7)
        v = mun + zeros(1,2*T);
        for i=1:(n-1)
            % Gaussian
            c(i) = randn*s(i);
            v = v + c(i)*U(:,i)';
        end
        
        vn(1,1:T) = v(1:T);
        vn(2,1:T) = v(T+1:2*T);
        qsamp = ElasticShooting(mu,vn);
        psamp = q_to_curve(qsamp);

        z = plot(psamp(1,:)+.32*idx,psamp(2,:),'LineWidth',2);
        axis equal off;
        idx=idx+1;
end